@@ -1,9 +1,8 @@
 use strict;
 use warnings;
-use 5.006; # warnings
-package Software::License;
+package Software::License 0.104007;
 # ABSTRACT: packages that provide templated software licenses
-$Software::License::VERSION = '0.103012';
+
 use Data::Section -setup => { header_re => qr/\A__([^_]+)__\Z/ };
 use Text::Template ();
 
@@ -22,8 +21,19 @@ use Text::Template ();
 #pod This method returns a new license object for the given license class.  Valid
 #pod arguments are:
 #pod
-#pod   holder - the holder of the copyright; required
-#pod   year   - the year of copyright; defaults to current year
+#pod =for :list
+#pod = holder
+#pod the holder of the copyright; required
+#pod = year
+#pod the year of copyright; defaults to current year
+#pod = program
+#pod the name of software for use in the middle of a sentence
+#pod = Program
+#pod the name of software for use in the beginning of a sentence
+#pod
+#pod C<program> and C<Program> arguments may be specified both, either one or none.
+#pod Each argument, if not specified, is defaulted to another one, or to properly
+#pod capitalized "this program", if both arguments are omitted.
 #pod
 #pod =cut
 
@@ -43,15 +53,38 @@ sub new {
 #pod
 #pod =cut
 
-sub year   { defined $_[0]->{year} ? $_[0]->{year} : (localtime)[5]+1900 }
+sub year   { $_[0]->{year} // (localtime)[5]+1900 }
 sub holder { $_[0]->{holder}     }
 
 sub _dotless_holder {
-    my $holder = $_[0]->holder;
-    $holder =~ s/\.$//;
-    return $holder;
+  my $holder = $_[0]->holder;
+  $holder =~ s/\.$//;
+  return $holder;
 }
 
+#pod =method program
+#pod
+#pod Name of software for using in the middle of a sentence.
+#pod
+#pod The method returns value of C<program> constructor argument (if it evaluates as true, i. e.
+#pod defined, non-empty, non-zero), or value of C<Program> constructor argument (if it is true), or
+#pod "this program" as the last resort.
+#pod
+#pod =cut
+
+sub program { $_[0]->{program} || $_[0]->{Program} || 'this program' }
+
+#pod =method Program
+#pod
+#pod Name of software for using in the middle of a sentence.
+#pod
+#pod The method returns value of C<Program> constructor argument (if it is true), or value of C<program>
+#pod constructor argument (if it is true), or "This program" as the last resort.
+#pod
+#pod =cut
+
+sub Program { $_[0]->{Program} || $_[0]->{program} || 'This program' }
+
 #pod =method name
 #pod
 #pod This method returns the name of the license, suitable for shoving in the middle
@@ -144,6 +177,15 @@ sub meta2_name {
   return undef;
 }
 
+#pod =method spdx_expression
+#pod
+#pod This method should return the string with the spdx identifier as indicated by
+#pod L<https://spdx.org/licenses/>
+#pod
+#pod =cut
+
+sub spdx_expression { return undef; }
+
 sub _fill_in {
   my ($self, $which) = @_;
 
@@ -177,10 +219,13 @@ sub _fill_in {
 #pod * L<Software::License::Apache_1_1>
 #pod * L<Software::License::Apache_2_0>
 #pod * L<Software::License::Artistic_1_0>
+#pod * L<Software::License::Artistic_1_0_Perl>
 #pod * L<Software::License::Artistic_2_0>
 #pod * L<Software::License::BSD>
 #pod * L<Software::License::CC0_1_0>
 #pod * L<Software::License::Custom>
+#pod * L<Software::License::EUPL_1_1>
+#pod * L<Software::License::EUPL_1_2>
 #pod * L<Software::License::FreeBSD>
 #pod * L<Software::License::GFDL_1_2>
 #pod * L<Software::License::GFDL_1_3>
@@ -202,6 +247,13 @@ sub _fill_in {
 #pod * L<Software::License::Sun>
 #pod * L<Software::License::Zlib>
 #pod
+#pod Extra licenses are maintained on CPAN in separate modules.
+#pod
+#pod The L<App::Software::License> module comes with a script
+#pod L<software-license|https://metacpan.org/pod/distribution/App-Software-License/script/software-license>,
+#pod which provides a command-line interface
+#pod to Software::License.
+#pod
 #pod =cut
 
 1;
@@ -216,7 +268,7 @@ Software::License - packages that provide templated software licenses
 
 =head1 VERSION
 
-version 0.103012
+version 0.104007
 
 =head1 SYNOPSIS
 
@@ -226,6 +278,20 @@ version 0.103012
 
   print $output_fh $license->fulltext;
 
+=head1 PERL VERSION
+
+This module is part of CPAN toolchain, or is treated as such.  As such, it
+follows the agreement of the Perl Toolchain Gang to require no newer version
+of perl than one released in the last ten years.  This version may change by
+agreement of the Toolchain Gang, but for now is governed by the L<Lancaster
+Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
+of 2013 and the Lyon Amendment of 2023 (described at the linked-to document).
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 METHODS
 
 =head2 new
@@ -235,8 +301,29 @@ version 0.103012
 This method returns a new license object for the given license class.  Valid
 arguments are:
 
-  holder - the holder of the copyright; required
-  year   - the year of copyright; defaults to current year
+=over 4
+
+=item holder
+
+the holder of the copyright; required
+
+=item year
+
+the year of copyright; defaults to current year
+
+=item program
+
+the name of software for use in the middle of a sentence
+
+=item Program
+
+the name of software for use in the beginning of a sentence
+
+=back
+
+C<program> and C<Program> arguments may be specified both, either one or none.
+Each argument, if not specified, is defaulted to another one, or to properly
+capitalized "this program", if both arguments are omitted.
 
 =head2 year
 
@@ -244,6 +331,21 @@ arguments are:
 
 These methods are attribute readers.
 
+=head2 program
+
+Name of software for using in the middle of a sentence.
+
+The method returns value of C<program> constructor argument (if it evaluates as true, i. e.
+defined, non-empty, non-zero), or value of C<Program> constructor argument (if it is true), or
+"this program" as the last resort.
+
+=head2 Program
+
+Name of software for using in the middle of a sentence.
+
+The method returns value of C<Program> constructor argument (if it is true), or value of C<program>
+constructor argument (if it is true), or "This program" as the last resort.
+
 =head2 name
 
 This method returns the name of the license, suitable for shoving in the middle
@@ -291,6 +393,11 @@ there is no known string to use.  If this method does not exist, and
 C<meta_name> returns open_source, restricted, unrestricted, or unknown, that
 value will be used.
 
+=head2 spdx_expression
+
+This method should return the string with the spdx identifier as indicated by
+L<https://spdx.org/licenses/>
+
 =head1 LOOKING UP LICENSE CLASSES
 
 If you have an entry in a F<META.yml> or F<META.json> file, or similar
@@ -331,6 +438,10 @@ L<Software::License::Artistic_1_0>
 
 =item *
 
+L<Software::License::Artistic_1_0_Perl>
+
+=item *
+
 L<Software::License::Artistic_2_0>
 
 =item *
@@ -347,6 +458,14 @@ L<Software::License::Custom>
 
 =item *
 
+L<Software::License::EUPL_1_1>
+
+=item *
+
+L<Software::License::EUPL_1_2>
+
+=item *
+
 L<Software::License::FreeBSD>
 
 =item *
@@ -427,18 +546,37 @@ L<Software::License::Zlib>
 
 =back
 
+Extra licenses are maintained on CPAN in separate modules.
+
+The L<App::Software::License> module comes with a script
+L<software-license|https://metacpan.org/pod/distribution/App-Software-License/script/software-license>,
+which provides a command-line interface
+to Software::License.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Bernardo Rechea Bernhard Amann bowtie Brian Cassidy Phillips Craig Scrivner Dave Rolsky David E. Wheeler Golden Dominique Dumont Dylan William Hardison Flavio Poletti Florian Ragwitz Graham Knop Kenichi Ishigaki magnolia mikegrb Shlomi Fish Syohei YOSHIDA
+=for stopwords Alex Kapranoff Andrew Grangaard Axel Beckert Bernardo Rechea Bernhard Amann bowtie Brian Cassidy Phillips Craig Scrivner Curtis Brandt Dave Rolsky David E. Wheeler Golden Dominique Dumont Dylan William Hardison Flavio Poletti Florian Ragwitz Graham Knop Justin Baker jvolkening Kang-min Liu Karen Etheridge Kenichi Ishigaki Kivanc Yazan Leon Timmermans magnolia Marcel Telka mikegrb Neil Bowers Nicolas Rochelemagne Olivier Mengué Pablo Rodríguez González Petr Písař Ricardo Signes Shlomi Fish srchulo Syohei YOSHIDA Tomasz Konojacki Van de Bugger Wesley Schwengle
 
 =over 4
 
 =item *
 
+Alex Kapranoff <kappa@yandex.ru>
+
+=item *
+
+Andrew Grangaard <granny-github@ofb.net>
+
+=item *
+
+Axel Beckert <abe@deuxchevaux.org>
+
+=item *
+
 Bernardo Rechea <brbpub@gmail.com>
 
 =item *
@@ -463,6 +601,10 @@ Craig Scrivner <scrivner@geology.cwu.edu>
 
 =item *
 
+Curtis Brandt <curtis@cpan.org>
+
+=item *
+
 Dave Rolsky <autarch@urth.org>
 
 =item *
@@ -495,29 +637,97 @@ Graham Knop <haarg@haarg.org>
 
 =item *
 
+Justin Baker <me@jbaker.dev>
+
+=item *
+
+jvolkening <jdv@base2bio.com>
+
+=item *
+
+Kang-min Liu <gugod@gugod.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
 Kenichi Ishigaki <ishigaki@cpan.org>
 
 =item *
 
+Kivanc Yazan <kivancyazan@gmail.com>
+
+=item *
+
+Leon Timmermans <fawaka@gmail.com>
+
+=item *
+
 magnolia <magnolia.k@me.com>
 
 =item *
 
+Marcel Telka <marcel@telka.sk>
+
+=item *
+
 mikegrb <mgreb@linode.com>
 
 =item *
 
+Neil Bowers <neil@bowers.com>
+
+=item *
+
+Nicolas Rochelemagne <rochelemagne@cpanel.net>
+
+=item *
+
+Olivier Mengué <dolmen@cpan.org>
+
+=item *
+
+Pablo Rodríguez González <pablo.rodriguez.gonzalez@gmail.com>
+
+=item *
+
+Petr Písař <ppisar@redhat.com>
+
+=item *
+
+Ricardo Signes <rjbs@semiotic.systems>
+
+=item *
+
 Shlomi Fish <shlomif@iglu.org.il>
 
 =item *
 
+srchulo <violapiratejunky@gmail.com>
+
+=item *
+
 Syohei YOSHIDA <syohex@gmail.com>
 
+=item *
+
+Tomasz Konojacki <me@xenu.pl>
+
+=item *
+
+Van de Bugger <van.de.bugger@gmail.com>
+
+=item *
+
+Wesley Schwengle <wesley@schwengle.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2025 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
