@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package Software::License::AGPL_3;
-$Software::License::AGPL_3::VERSION = '0.103011';
+package Software::License::AGPL_3 0.104007;
+
 use parent 'Software::License';
 # ABSTRACT: GNU Affero General Public License, Version 3
 
@@ -10,6 +10,7 @@ sub url  { 'http://www.gnu.org/licenses/agpl-3.0.txt' }
 
 sub meta_name  { 'open_source' }
 sub meta2_name { 'agpl_3' }
+sub spdx_expression { 'AGPL-3.0' }
 
 1;
 
@@ -23,15 +24,29 @@ Software::License::AGPL_3 - GNU Affero General Public License, Version 3
 
 =head1 VERSION
 
-version 0.103011
+version 0.104007
+
+=head1 PERL VERSION
+
+This module is part of CPAN toolchain, or is treated as such.  As such, it
+follows the agreement of the Perl Toolchain Gang to require no newer version
+of perl than one released in the last ten years.  This version may change by
+agreement of the Toolchain Gang, but for now is governed by the L<Lancaster
+Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
+of 2013 and the Lyon Amendment of 2023 (described at the linked-to document).
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2025 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
